@@ -79,6 +79,8 @@ capplet_new (CappletDir *dir, gchar *desktop_path)
 	g_free (path);
 
 	capplet = g_new0 (Capplet, 1);
+	capplet->launching = FALSE;
+
 	entry = CAPPLET_DIR_ENTRY (capplet);
 
 	entry->type = TYPE_CAPPLET;
@@ -194,6 +196,13 @@ capplet_dir_entry_shutdown (CappletDirEntry *entry)
 		g_assert_not_reached ();
 }
 
+static gint
+capplet_reset_cb (Capplet *capplet) 
+{
+	capplet->launching = FALSE;
+	return FALSE;
+}
+
 static void
 capplet_activate (Capplet *capplet) 
 {
@@ -202,14 +211,28 @@ capplet_activate (Capplet *capplet)
 	entry = CAPPLET_DIR_ENTRY (capplet)->entry;
 
 #warning FIXME: this should probably be root-manager-helper
-#if 0
-	if (!strncmp (entry->exec[0], "gnomecc", strlen ("gnomecc")))
-		capplet_control_launch (entry->exec[2], entry->name);
+#ifdef HAVE_BONOBO
+	if (!strncmp (entry->exec[0], "gnomecc", strlen ("gnomecc"))) {
+		if (capplet->launching) {
+			return;
+		} else {
+			capplet->launching = TRUE;
+			gtk_idle_add ((GtkFunction) capplet_reset_cb, capplet);
+			capplet_control_launch (entry->exec[2], entry->name);
+		}
+	} else
 #endif
-	if (!strncmp (entry->exec[0], "root-manager", strlen ("root-manager")))
+	if (!strncmp (entry->exec[0], "root-manager", strlen ("root-manager"))) {
 		start_capplet_through_root_manager (entry);
-	else
-		gnome_desktop_entry_launch (entry);
+	} else {
+		if (capplet->launching) {
+			return;
+		} else {
+			capplet->launching = TRUE;
+			gtk_timeout_add (1000, (GtkFunction) capplet_reset_cb, capplet);
+			gnome_desktop_entry_launch (entry);
+		}
+	}
 }
 
 void
@@ -422,6 +445,8 @@ capplet_cancel_cb (GtkWidget *widget, GtkWidget *app)
 	CORBA_exception_free (&ev);
 }
 
+#ifdef HAVE_BONOBO
+
 /* capplet_control_launch
  *
  * Launch a capplet as a Bonobo control; returns the relevant BonoboWindow or
@@ -462,12 +487,6 @@ capplet_control_launch (const gchar *capplet_name, gchar *window_title)
 	property_control = bonobo_get_object (oaf_iid, "IDL:Bonobo/PropertyControl:1.0", &ev);
 	g_free (oaf_iid);
 
-	if (BONOBO_EX (&ev) && !strcmp (ev._repo_id, "IDL:Bonobo/Moniker/InterfaceNotFound:1.0")) {
-		/* Capplet is already running in this case */
-		g_free (moniker);
-		return NULL;
-	}
-
 	if (BONOBO_EX (&ev) || property_control == CORBA_OBJECT_NIL) {
 		dialog = gnome_error_dialog ("Could not load the capplet.");
 		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
@@ -518,3 +537,5 @@ capplet_control_launch (const gchar *capplet_name, gchar *window_title)
 
 	return app;
 }
+
+#endif /* HAVE_BONOBO */
